@@ -254,6 +254,9 @@ def set_idemailstatus_target_column(df):
         bv_col = df['BV']
         df.drop(labels=['BV'], axis=1, inplace=True)
         df.insert(loc=2, value=bv_col, column='BV')
+        idcampaign_col = df['idCampaign']
+        df.drop(labels=['idCampaign'], axis=1, inplace=True)
+        df.insert(loc=3, value=idcampaign_col, column='BV')
 
     else:
         logger.error('No IDEmailSTatus column found')
@@ -450,7 +453,7 @@ def fill_variables(df):
         'DaysSinceFirstContact': 0,
         'NumFoundingRounds': 0,
         'FundingAmount': 0,
-        'DaysSinceLastSeed': 0
+        'DaysSinceLastSeed': 99999
     }
 
     for key in variables_dict.keys():
@@ -584,9 +587,7 @@ def create_class_dictionaries(df_original,class_to_use:str):
              (df['IDEmailStatus'] != 31), 'IDEmailStatus'] = 0
     df.loc[df['IDEmailStatus'] == 14, 'IDEmailStatus'] = 1
     df.loc[df['IDEmailStatus'] == 31, 'IDEmailStatus'] = 1
-
-    logger.info(f"{df['BV'].value_counts(dropna=False)}")
-    groupby = df.groupby(class_to_use).agg(BV=('BV', 'mean'),
+    groupby = df.groupby(class_to_use,dropna=False).agg(BV=('BV', 'mean'),
                                            Conversions=('IDEmailStatus', 'mean')
                                            )
     groupby = groupby.reset_index()
